@@ -88,8 +88,8 @@ MDNavigationLayout:
                         ]
                     right_action_items:
                         [
-                        ['webhook', lambda x: root.ids.screen_manager.app.connectivity_status(self)],
                         ['access-point', lambda x: root.ids.screen_manager.app.announce_now_action(self)],
+                        ['webhook', lambda x: root.ids.screen_manager.app.connectivity_status(self)],
                         ['qrcode', lambda x: root.ids.screen_manager.app.ingest_lxm_action(self)],
                         ['email-sync', lambda x: root.ids.screen_manager.app.lxmf_sync_action(self)],
                         ['account-plus', lambda x: root.ids.screen_manager.app.new_conversation_action(self)],
@@ -1085,7 +1085,7 @@ MDNavigationLayout:
                                 height: dp(48)
                                 
                                 MDLabel:
-                                    text: "Announce At App Startup"
+                                    text: "Announce Automatically"
                                     font_style: "H6"
 
                                 MDSwitch:
@@ -1189,6 +1189,22 @@ MDNavigationLayout:
                                     disabled: True
                                     active: False
 
+                            MDBoxLayout:
+                                orientation: "horizontal"
+                                size_hint_y: None
+                                padding: [0,0,dp(24),dp(0)]
+                                height: dp(48)
+                                
+                                MDLabel:
+                                    text: "Debug Logging"
+                                    font_style: "H6"
+
+                                MDSwitch:
+                                    id: settings_debug
+                                    pos_hint: {"center_y": 0.3}
+                                    disabled: False
+                                    active: False
+
         MDScreen:
             name: "hardware_screen"
             
